use Test::More 'no_plan';

use_ok('Bio::PhyloXS::Forest::Node');
use_ok('Bio::PhyloXS::Forest::Tree');
use_ok('Bio::PhyloXS::Identifiable');
use_ok('Bio::PhyloXS::Listable');
use_ok('Bio::PhyloXS::Matrices::Datatype');
use_ok('Bio::PhyloXS::NeXML::Writable');
use_ok('Bio::PhyloXS');

use_ok('Bio::PhyloXS::Matrices::Character');
use_ok('Bio::PhyloXS::Matrices::Characters');
use_ok('Bio::PhyloXS::Matrices::Datum');
use_ok('Bio::PhyloXS::Matrices::Matrix');
use_ok('Bio::PhyloXS::Matrices::TypeSafeData');