## This file generated by InlineX::C2XS (version 0.25) using Inline::C (version 0.78)
package Bio::PhyloXS;

require Exporter;
*import = \&Exporter::import;
require DynaLoader;

our $VERSION = 'v0.1.0';
$VERSION = eval $VERSION;
DynaLoader::bootstrap Bio::PhyloXS $VERSION;

@Bio::PhyloXS::EXPORT = ();
@Bio::PhyloXS::EXPORT_OK = ();

sub dl_load_flags {0} # Prevent DynaLoader from complaining and croaking
BEGIN {
	use Bio::Phylo::Factory;
	my $fac = Bio::Phylo::Factory->new;
	$fac->register_class('Bio::PhyloXS::Forest::Node');
	$fac->register_class('Bio::PhyloXS::Forest::Tree');
}
use version 0.77; our $VERSION = qv("v0.1.0");
__PACKAGE__