## This file generated by InlineX::C2XS (version 0.25) using Inline::C (version 0.78)
package Bio::PhyloXS::Identifiable;

require Exporter;
*import = \&Exporter::import;
require DynaLoader;

our $VERSION = 'v0.1.0';
$VERSION = eval $VERSION;
DynaLoader::bootstrap Bio::PhyloXS::Identifiable $VERSION;

@Bio::PhyloXS::Identifiable::EXPORT = ();
@Bio::PhyloXS::Identifiable::EXPORT_OK = ();

sub dl_load_flags {0} # Prevent DynaLoader from complaining and croaking
use Carp;

sub new {
	my $class = shift;	
	my $self = $class->create;
	my %args = @_;
	for my $key ( keys %args ) {
		my $method = $key;
		$method =~ s/^-/set_/;
		$self->$method($args{$key});
	}
	return $self;
}

sub DESTROY {
	my $self = shift;
	my $class = ref $self;
	$class =~ s/.+://;
	my $destructor = 'destroy_' . lc $class;
	$self->$destructor;
}

__PACKAGE__;