## This file generated by InlineX::C2XS (version 0.25) using Inline::C (version 0.78)
package Bio::PhyloXS::Listable;

require Exporter;
*import = \&Exporter::import;
require DynaLoader;

our $VERSION = 'v0.1.0';
$VERSION = eval $VERSION;
DynaLoader::bootstrap Bio::PhyloXS::Listable $VERSION;

@Bio::PhyloXS::Listable::EXPORT = ();
@Bio::PhyloXS::Listable::EXPORT_OK = ();

sub dl_load_flags {0} # Prevent DynaLoader from complaining and croaking
use base 'Bio::PhyloXS::NeXML::Writable';
__PACKAGE__;